hedgewars/uGame.pas
changeset 10861 d84c725fe332
parent 10316 0f46fb0e0d5f
child 11026 b8022f4bea14
--- a/hedgewars/uGame.pas	Wed Mar 18 21:03:53 2015 +0100
+++ b/hedgewars/uGame.pas	Wed Mar 18 23:13:37 2015 +0300
@@ -102,8 +102,9 @@
         if isInLag then
             case GameType of
                 gmtNet: begin
                         // just update the health bars
                         AddVisualGear(0, 0, vgtTeamHealthSorter);
+                        AddVisualGear(0, 0, vgtSmoothWindBar);
                         break;
                         end;
                 gmtDemo, gmtRecord: begin
@@ -102,8 +102,9 @@
             case GameType of
                 gmtNet: begin
-                        // just update the health bars
+                        // update health bars and the wind indicator
                         AddVisualGear(0, 0, vgtTeamHealthSorter);